==> jaguar_generator-0.2.3.tar.gz: lib/writer/interceptor_create.dart <==
part of jaguar_generator.writer;

class InterceptorCreateWriter {
  final Route _r;

  final Interceptor _i;

  InterceptorCreateWriter(this._r, this._i);

  InterceptorCreator get _c => _i.creator;

  String generate() {
    StringBuffer sb = new StringBuffer();

    sb.write('${_i.genInstanceName} = new ${_c.name}(');

    for (dynamic param in _c.required) {
      if(param is InterceptorRequiredParamReprod) {
        sb.write(param.source);
      } else if(param is InterceptorMakeParam) {
        sb.write(_makeParam(param));
      } else {
        //TODO throw
      }
      sb.write(',');
    }

    for (dynamic param in _c.optional) {
      if(param is InterceptorNamedParamReprod) {
        sb.write(param.source);
      } else if(param is InterceptorMakeParam) {
        sb.write('${param.key}: ');
        sb.write(_makeParam(param));
      } else {
        //TODO throw
      }
      sb.write(',');
    }

    sb.writeln(').createInterceptor();');

    return sb.toString();
  }
}

String _makeParam(InterceptorMakeParam param) {
  StringBuffer sb = new StringBuffer();
  if (param is InterceptorMakeParamType) {
    sb.write('new ${param.type}(');
    sb.write(param.inputs.map((inp) => inp.writeVal).join(','));
    sb.write(')');
  } else if (param is InterceptorMakeParamMethod) {
    if (param.isAsync) {
      sb.write('await ');
    }
    sb.write('${param.methodName}()');
  } else if (param is InterceptorMakeParamSettings) {
    sb.write('Settings.getString(');
    sb.write('"${param.settingKey}"');
    if (param.defaultValue != null) {
      sb.write(', defaultValue: "${param.defaultValue}"');
    }
    if (param.filterStr != null) {
      sb.write(', settingsFilter: SettingsFilter.${param.filterStr}');
    }
    sb.write(')');
  } else {
    //TODO throw
  }
  return sb.toString();
}

==> jaguar_generator-0.2.4.tar.gz: lib/writer/interceptor_create.dart <==
part of jaguar_generator.writer;

class InterceptorCreateWriter {
  final Route _r;

  final Interceptor _i;

  InterceptorCreateWriter(this._r, this._i);

  InterceptorCreator get _c => _i.creator;

  String generate() {
    StringBuffer sb = new StringBuffer();

    sb.write('${_i.genInstanceName} = new ${_c.name}(');

    for (dynamic param in _c.required) {
      if(param is InterceptorRequiredParamReprod) {
        sb.write(param.source);
      } else if(param is InterceptorMakeParam) {
        sb.write(_makeParam(param));
      } else {
        //TODO throw
      }
      sb.write(',');
    }

    for (dynamic param in _c.optional) {
      if(param is InterceptorNamedParamReprod) {
        sb.write(param.source);
      } else if(param is InterceptorMakeParam) {
        sb.write('${param.key}: ');
        sb.write(_makeParam(param));
      } else {
        //TODO throw
      }
      sb.write(',');
    }

    sb.writeln(').createInterceptor();');

    return sb.toString();
  }
}

String _makeParam(InterceptorMakeParam param) {
  StringBuffer sb = new StringBuffer();
  if (param is InterceptorMakeParamMethod) {
    if (param.isAsync) {
      sb.write('await ');
    }
    sb.write('${param.methodName}()');
  } else if (param is InterceptorMakeParamSettings) {
    sb.write('Settings.getString(');
    sb.write('"${param.settingKey}"');
    if (param.defaultValue != null) {
      sb.write(', defaultValue: "${param.defaultValue}"');
    }
    if (param.filterStr != null) {
      sb.write(', settingsFilter: SettingsFilter.${param.filterStr}');
    }
    sb.write(')');
  } else {
    //TODO throw
  }
  return sb.toString();
}
